#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-plugin-api
version:              2.3.0.0
visibility:           public
id:                   hls-plugin-api-2.3.0.0-AhlgRZkAJwO1JNQXcdgGea
key:                  hls-plugin-api-2.3.0.0-AhlgRZkAJwO1JNQXcdgGea
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Haskell Language Server API for plugin communication
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  f9f5266ba3e1f83ff0b8f2600a274f30
exposed:              True
exposed-modules:
    Ide.Logger Ide.Plugin.Config Ide.Plugin.ConfigUtils
    Ide.Plugin.Error Ide.Plugin.Properties Ide.Plugin.RangeMap
    Ide.Plugin.Resolve Ide.PluginUtils Ide.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-plugin-api-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-plugin-api-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-plugin-api-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-plugin-api
hs-libraries:         HShls-plugin-api-2.3.0.0-AhlgRZkAJwO1JNQXcdgGea
depends:
    Diff-1.0-51T9Z3lXl7dCcFt1EsHt5x
    aeson-2.2.2.0-EwrTYsTfELe3d4orbILmv4 base-4.18.2.1
    co-log-core-0.3.2.7-F1O34oOHUJ28GHaQylQqCF containers-0.6.7
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    dependent-map-0.4.0.1-KwBWrPhPx2r6TsKkh7jfv8
    dependent-sum-0.7.2.0-JFXwV470eKSHqaaFepNmoh
    dlist-1.0-F3vtDhl0dJJ2wapcm5Bnp extra-1.7.16-J2nH1si97LP2pkcRW1gnIU
    filepath-1.4.300.1 ghc-9.6.6 hashable-1.4.7.0-8JCT2FqI0OIc7eryHiY9E
    hls-graph-2.3.0.0-EU51DDfcYUwD92bxTtun9V
    hw-fingertree-0.1.2.1-AcT8RcG7444EqeeCrzza3S
    lens-5.3.5-EhGtUvREmRw93iKAzI3qoD
    lens-aeson-1.2.3-6EwpcermvEA2i8uuq4SxTu
    lsp-2.2.0.0-JJwazOJIAzCJL4eJNeKzRs
    megaparsec-9.7.1-4UEkY3VkDbeLSqlGrcJOet mtl-2.3.1
    opentelemetry-0.8.0-LhTWWXgk49mJCpz4ym7fyd
    optparse-applicative-0.18.1.0-2OPlFtvlr5yI8qFRB5F8bn
    prettyprinter-1.7.2-JipenGj1ZXCGzFGneLGC87
    regex-tdfa-1.3.2.5-5Xsa8Nkm5ozG5wMRmCPABC
    row-types-1.0.1.2-1f5yLbkG6K71ceef6ccZZw stm-2.5.1.0 text-2.0.2
    time-1.12.2 transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-5kFyykBV8QLAHqHdpZTooL
    unordered-containers-0.2.21-KyMpciGvYH9aykbB6p5Z

haddock-interfaces:
    /usr/share/doc/haskell-hls-plugin-api/html/hls-plugin-api.haddock

haddock-html:         /usr/share/doc/haskell-hls-plugin-api/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

